==> goValidOJS-ojs33-v1.3.3.0.zip: goValidOJS/classes/GoValidOJSSettingsForm.inc.php <==
<?php

/**
 * @file plugins/generic/govalidOJS/classes/GoValidOJSSettingsForm.inc.php
 *
 * Copyright (c) 2025 Naufal Naufal, University Of Muhammadiyah Makassar, Indonesia
 * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 *
 * @class GoValidOJSSettingsForm
 * @ingroup plugins_generic_govalidOJS
 *
 * @brief Form for journal managers to modify GoValid OJS plugin settings
 *
 * Converted for OJS 3.3.x compatibility
 */

import('lib.pkp.classes.form.Form');

class GoValidOJSSettingsForm extends Form {

    /** @var int */
    var $_contextId;

    /** @var GoValidOJSPlugin */
    var $_plugin;

    /**
     * Constructor
     *
     * @param $plugin GoValidOJSPlugin
     * @param $contextId int
     */
    function __construct($plugin, $contextId) {
        $this->_contextId = $contextId;
        $this->_plugin = $plugin;

        parent::__construct($plugin->getTemplateResource('settingsForm.tpl'));

        // Add form checks
        $this->addCheck(new FormValidatorPost($this));
        $this->addCheck(new FormValidatorCSRF($this));
    }

    /**
     * Initialize form data.
     */
    function initData() {
        $this->_data = array(
            // FAB visibility settings - default all to true
            'showFabForManagers' => $this->_plugin->getSetting($this->_contextId, 'showFabForManagers') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForManagers') : true,
            'showFabForEditors' => $this->_plugin->getSetting($this->_contextId, 'showFabForEditors') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForEditors') : true,
            'showFabForCopyeditors' => $this->_plugin->getSetting($this->_contextId, 'showFabForCopyeditors') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForCopyeditors') : true,
            'showFabForAssistants' => $this->_plugin->getSetting($this->_contextId, 'showFabForAssistants') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForAssistants') : true,
            // Smart Verify Widget settings - default disabled
            'enableSmartVerifyWidget' => $this->_plugin->getSetting($this->_contextId, 'enableSmartVerifyWidget') ? true : false,
            'smartVerifyWidgetPosition' => $this->_plugin->getSetting($this->_contextId, 'smartVerifyWidgetPosition') ?: 'bottom-right',
        );
    }

    /**
     * Assign form data to user-submitted data.
     */
    function readInputData() {
        $this->readUserVars(array(
            'showFabForManagers',
            'showFabForEditors',
            'showFabForCopyeditors',
            'showFabForAssistants',
            'enableSmartVerifyWidget',
            'smartVerifyWidgetPosition',
        ));
    }

    /**
     * @copydoc Form::fetch()
     */
    function fetch($request, $template = null, $display = false) {
        $templateMgr = TemplateManager::getManager($request);
        $templateMgr->assign('pluginName', $this->_plugin->getName());

        // FAB visibility settings
        $templateMgr->assign('showFabForManagers', $this->getData('showFabForManagers'));
        $templateMgr->assign('showFabForEditors', $this->getData('showFabForEditors'));
        $templateMgr->assign('showFabForCopyeditors', $this->getData('showFabForCopyeditors'));
        $templateMgr->assign('showFabForAssistants', $this->getData('showFabForAssistants'));

        // Smart Verify Widget settings
        $templateMgr->assign('enableSmartVerifyWidget', $this->getData('enableSmartVerifyWidget'));
        $templateMgr->assign('smartVerifyWidgetPosition', $this->getData('smartVerifyWidgetPosition'));

        // Designer URLs
        $context = $request->getContext();
        $contextPath = $context ? $context->getPath() : 'index';

        $designerUrl = $request->getBaseUrl() . '/index.php/' . $contextPath . '/govalidojs/designer';
        $templateMgr->assign('designerUrl', $designerUrl);

        $emailTemplateManagerUrl = $request->getBaseUrl() . '/index.php/' . $contextPath . '/govalidojs/emailTemplateDesigner';
        $templateMgr->assign('emailTemplateManagerUrl', $emailTemplateManagerUrl);

        return parent::fetch($request, $template, $display);
    }

    /**
     * @copydoc Form::execute()
     */
    function execute(...$functionArgs) {
        // Save FAB visibility settings
        $this->_plugin->updateSetting($this->_contextId, 'showFabForManagers', $this->getData('showFabForManagers') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForEditors', $this->getData('showFabForEditors') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForCopyeditors', $this->getData('showFabForCopyeditors') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForAssistants', $this->getData('showFabForAssistants') ? true : false, 'bool');

        // Save Smart Verify Widget settings
        $this->_plugin->updateSetting($this->_contextId, 'enableSmartVerifyWidget', $this->getData('enableSmartVerifyWidget') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'smartVerifyWidgetPosition', $this->getData('smartVerifyWidgetPosition') ?: 'bottom-right', 'string');

        parent::execute(...$functionArgs);
    }
}

==> goValidOJS-ojs33-v1.3.6.1.zip: goValidOJS/classes/GoValidOJSSettingsForm.inc.php <==
<?php

/**
 * @file plugins/generic/govalidOJS/classes/GoValidOJSSettingsForm.inc.php
 *
 * Copyright (c) 2025 Naufal Naufal, University Of Muhammadiyah Makassar, Indonesia
 * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 *
 * @class GoValidOJSSettingsForm
 * @ingroup plugins_generic_govalidOJS
 *
 * @brief Form for journal managers to modify GoValid OJS plugin settings
 *
 * Converted for OJS 3.3.x compatibility
 */

import('lib.pkp.classes.form.Form');

class GoValidOJSSettingsForm extends Form {

    /** @var int */
    var $_contextId;

    /** @var GoValidOJSPlugin */
    var $_plugin;

    /**
     * Constructor
     *
     * @param $plugin GoValidOJSPlugin
     * @param $contextId int
     */
    function __construct($plugin, $contextId) {
        $this->_contextId = $contextId;
        $this->_plugin = $plugin;

        parent::__construct($plugin->getTemplateResource('settingsForm.tpl'));

        // Add form checks
        $this->addCheck(new FormValidatorPost($this));
        $this->addCheck(new FormValidatorCSRF($this));
    }

    /**
     * Initialize form data.
     */
    function initData() {
        $this->_data = array(
            // FAB visibility settings - default all to true
            'showFabForManagers' => $this->_plugin->getSetting($this->_contextId, 'showFabForManagers') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForManagers') : true,
            'showFabForEditors' => $this->_plugin->getSetting($this->_contextId, 'showFabForEditors') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForEditors') : true,
            'showFabForCopyeditors' => $this->_plugin->getSetting($this->_contextId, 'showFabForCopyeditors') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForCopyeditors') : true,
            'showFabForAssistants' => $this->_plugin->getSetting($this->_contextId, 'showFabForAssistants') !== null ?
                $this->_plugin->getSetting($this->_contextId, 'showFabForAssistants') : true,
            // Smart Verify Widget settings - default disabled
            'enableSmartVerifyWidget' => $this->_plugin->getSetting($this->_contextId, 'enableSmartVerifyWidget') ? true : false,
            'smartVerifyWidgetPosition' => $this->_plugin->getSetting($this->_contextId, 'smartVerifyWidgetPosition') ?: 'bottom-right',
        );
    }

    /**
     * Assign form data to user-submitted data.
     */
    function readInputData() {
        $this->readUserVars(array(
            'showFabForManagers',
            'showFabForEditors',
            'showFabForCopyeditors',
            'showFabForAssistants',
            'enableSmartVerifyWidget',
            'smartVerifyWidgetPosition',
        ));
    }

    /**
     * @copydoc Form::fetch()
     */
    function fetch($request, $template = null, $display = false) {
        $templateMgr = TemplateManager::getManager($request);
        $templateMgr->assign('pluginName', $this->_plugin->getName());

        // FAB visibility settings
        $templateMgr->assign('showFabForManagers', $this->getData('showFabForManagers'));
        $templateMgr->assign('showFabForEditors', $this->getData('showFabForEditors'));
        $templateMgr->assign('showFabForCopyeditors', $this->getData('showFabForCopyeditors'));
        $templateMgr->assign('showFabForAssistants', $this->getData('showFabForAssistants'));

        // Smart Verify Widget settings
        $templateMgr->assign('enableSmartVerifyWidget', $this->getData('enableSmartVerifyWidget'));
        $templateMgr->assign('smartVerifyWidgetPosition', $this->getData('smartVerifyWidgetPosition'));

        // Designer URLs
        $context = $request->getContext();
        $contextPath = $context ? $context->getPath() : 'index';

        $designerUrl = $request->getBaseUrl() . '/index.php/' . $contextPath . '/govalidojs/designer';
        $templateMgr->assign('designerUrl', $designerUrl);

        $emailTemplateManagerUrl = $request->getBaseUrl() . '/index.php/' . $contextPath . '/govalidojs/emailTemplateDesigner';
        $templateMgr->assign('emailTemplateManagerUrl', $emailTemplateManagerUrl);

        // Get plugin version directly from version.xml
        $versionFile = $this->_plugin->getPluginPath() . '/version.xml';
        $pluginVersion = '1.0.0';
        if (file_exists($versionFile)) {
            $versionXml = simplexml_load_file($versionFile);
            if ($versionXml && isset($versionXml->release)) {
                $pluginVersion = (string)$versionXml->release;
            }
        }
        $templateMgr->assign('pluginVersion', $pluginVersion);

        return parent::fetch($request, $template, $display);
    }

    /**
     * @copydoc Form::execute()
     */
    function execute(...$functionArgs) {
        // Save FAB visibility settings
        $this->_plugin->updateSetting($this->_contextId, 'showFabForManagers', $this->getData('showFabForManagers') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForEditors', $this->getData('showFabForEditors') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForCopyeditors', $this->getData('showFabForCopyeditors') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'showFabForAssistants', $this->getData('showFabForAssistants') ? true : false, 'bool');

        // Save Smart Verify Widget settings
        $this->_plugin->updateSetting($this->_contextId, 'enableSmartVerifyWidget', $this->getData('enableSmartVerifyWidget') ? true : false, 'bool');
        $this->_plugin->updateSetting($this->_contextId, 'smartVerifyWidgetPosition', $this->getData('smartVerifyWidgetPosition') ?: 'bottom-right', 'string');

        parent::execute(...$functionArgs);
    }
}
